| Title: | Pathways from the NCI Pathways Database |
|---|---|
| Description: | Provides various methods to load the pathways from the NCI Pathways Database in R graph objects and to re-format them. |
| Authors: | Laurent Jacob |
| Maintainer: | Laurent Jacob <[email protected]> |
| License: | GPL-3 |
| Version: | 1.61.1 |
| Built: | 2026-05-29 21:57:23 UTC |
| Source: | https://github.com/bioc/NCIgraph |
Uses a breadth first search on a directed graph to identify which genes are regulated by a particular node in the graph.
directedBFS(g, node)directedBFS(g, node)
g |
A |
node |
A node of g. |
A structured list containing the regulated genes and the
type of interaction between node and each gene.
Laurent Jacob
Identifies edges that should be merged to parse a NCI network.
edgesToMerge(g)edgesToMerge(g)
g |
A |
A list of edges to be merged
Laurent Jacob
Loads networks from Cytoscape and parses them.
getNCIPathways(cyList=NULL, parseNetworks=TRUE, entrezOnly=TRUE, verbose=FALSE)getNCIPathways(cyList=NULL, parseNetworks=TRUE, entrezOnly=TRUE, verbose=FALSE)
cyList |
a |
verbose |
If |
parseNetworks |
A |
entrezOnly |
A |
A list of two elements: pList, a list of graphNEL objects,
and failedW a list containing the names of the networks that R
failed to read from cytoscape.
Laurent Jacob
##------------------------------ ## Load NCIgraph ##------------------------------ library(NCIgraph) ##------------------------------ ## Example 1: with Cytoscape ##------------------------------ ## Must have Cytoscape running with some networks open and CyREST plugin started. ## In this case, getNCIPathways will both read the raw networks from Cytoscape and parse them. ## Not run: grList <- getNCIPathways(cyList=NULL, parseNetworks=TRUE, entrezOnly=TRUE, verbose=TRUE)$pList ## End(Not run) ##------------------------------ ## Example 2: without Cytoscape ##------------------------------ ## Get some raw networks data("NCIgraphVignette", package="NCIgraph") ## When passed a non null cyList argument (a list of networks), ## getNCIPathways will simply parse the list of networks grList <- getNCIPathways(cyList=NCI.demo.cyList, parseNetworks=TRUE, entrezOnly=TRUE, verbose=TRUE)$pList##------------------------------ ## Load NCIgraph ##------------------------------ library(NCIgraph) ##------------------------------ ## Example 1: with Cytoscape ##------------------------------ ## Must have Cytoscape running with some networks open and CyREST plugin started. ## In this case, getNCIPathways will both read the raw networks from Cytoscape and parse them. ## Not run: grList <- getNCIPathways(cyList=NULL, parseNetworks=TRUE, entrezOnly=TRUE, verbose=TRUE)$pList ## End(Not run) ##------------------------------ ## Example 2: without Cytoscape ##------------------------------ ## Get some raw networks data("NCIgraphVignette", package="NCIgraph") ## When passed a non null cyList argument (a list of networks), ## getNCIPathways will simply parse the list of networks grList <- getNCIPathways(cyList=NCI.demo.cyList, parseNetworks=TRUE, entrezOnly=TRUE, verbose=TRUE)$pList
Returns a list of @KEGGEdgeSubType objects describing each edge of the NCI network.
getSubtype.NCIgraph(object)getSubtype.NCIgraph(object)
object |
An |
A list of KEGGEdgeSubType objects.
Laurent Jacob
##------------------------------ ## Load NCIgraph ##------------------------------ library(NCIgraph) ##------------------------------ ## Get some raw networks ##------------------------------ data("NCIgraphVignette", package="NCIgraph") ##------------------------------ ## Parse them ##------------------------------ grList <- getNCIPathways(cyList=NCI.demo.cyList, parseNetworks=TRUE, entrezOnly=TRUE, verbose=TRUE)$pList ##---------------------------------------------------------------- ## ## Get the subtype of the second network. Some activation and some ## inhibition edges. ## ##---------------------------------------------------------------- getSubtype.NCIgraph(grList[[2]])##------------------------------ ## Load NCIgraph ##------------------------------ library(NCIgraph) ##------------------------------ ## Get some raw networks ##------------------------------ data("NCIgraphVignette", package="NCIgraph") ##------------------------------ ## Parse them ##------------------------------ grList <- getNCIPathways(cyList=NCI.demo.cyList, parseNetworks=TRUE, entrezOnly=TRUE, verbose=TRUE)$pList ##---------------------------------------------------------------- ## ## Get the subtype of the second network. Some activation and some ## inhibition edges. ## ##---------------------------------------------------------------- getSubtype.NCIgraph(grList[[2]])
Assess whether a graph is a NCI graph.
is.NCIgraph(gr)is.NCIgraph(gr)
gr |
A |
A logical, TRUE if the graph is a NCI graph, FALSE otherwise.
Laurent Jacob
Merges a given list of nodes in a graph.
mergeNodes(g, mEdges, separateEntrez=TRUE, entrezOnly=TRUE)mergeNodes(g, mEdges, separateEntrez=TRUE, entrezOnly=TRUE)
g |
A |
mEdges |
A |
separateEntrez |
|
entrezOnly |
A |
The updated graph object
Laurent Jacob
These are the ten first elements of the full list of raw networks that can be downloaded using the downloadCyLists.R script.
NCI.demo.cyListNCI.demo.cyList
A list of 10 graphNEL objects.
Laurent Jacob
data("NCIgraphVignette") length(NCI.demo.cyList) library(Rgraphviz) plot(NCI.demo.cyList[[1]])data("NCIgraphVignette") length(NCI.demo.cyList) library(Rgraphviz) plot(NCI.demo.cyList[[1]])
Package: NCIgraph
Class NCIgraph
public static class NCIgraph
extends graphNELObject
Class extending graphNEL fro graphs build from NCI gene networks.
Laurent Jacob
Takes a NCI network and transforms it into a simpler graph only representing inhibition/activation relationships between genes.
parseNCInetwork(g, propagateReg=TRUE, separateEntrez=TRUE, mergeEntrezCopies=TRUE, entrezOnly=TRUE)parseNCInetwork(g, propagateReg=TRUE, separateEntrez=TRUE, mergeEntrezCopies=TRUE, entrezOnly=TRUE)
g |
A |
propagateReg |
A |
separateEntrez |
|
mergeEntrezCopies |
A |
entrezOnly |
A |
The new graph object.
Laurent Jacob
## Load NCIgraph library(NCIgraph) ## Get some raw networks data("NCIgraphVignette", package="NCIgraph") ## Parse the first of them parsedNetwork <- parseNCInetwork(NCI.demo.cyList[[1]],propagateReg=TRUE,separateEntrez=TRUE,mergeEntrezCopies=TRUE,entrezOnly=TRUE)## Load NCIgraph library(NCIgraph) ## Get some raw networks data("NCIgraphVignette", package="NCIgraph") ## Parse the first of them parsedNetwork <- parseNCInetwork(NCI.demo.cyList[[1]],propagateReg=TRUE,separateEntrez=TRUE,mergeEntrezCopies=TRUE,entrezOnly=TRUE)
Transforms the network in a way that each Biochemical Reaction node pointing to a Complex points to what is regulated by the complex and updates the interaction types accordingly.
propagateRegulation(g)propagateRegulation(g)
g |
A |
The updated graph object
Laurent Jacob
Gives the entrezID corresponding to the nodes of a graph.
translateNCI2GeneID(g)translateNCI2GeneID(g)
g |
A |
A vector of character giving the entrez ID of the nodes of g.
Laurent Jacob
##------------------------------ ## Load NCIgraph ##------------------------------ library(NCIgraph) ## Get some raw networks data("NCIgraphVignette", package="NCIgraph") ## Parse them grList <- getNCIPathways(cyList=NCI.demo.cyList, parseNetworks=TRUE, entrezOnly=TRUE, verbose=TRUE)$pList ## Get the gene ids for the first of them gids <- translateNCI2GeneID(grList[[1]])##------------------------------ ## Load NCIgraph ##------------------------------ library(NCIgraph) ## Get some raw networks data("NCIgraphVignette", package="NCIgraph") ## Parse them grList <- getNCIPathways(cyList=NCI.demo.cyList, parseNetworks=TRUE, entrezOnly=TRUE, verbose=TRUE)$pList ## Get the gene ids for the first of them gids <- translateNCI2GeneID(grList[[1]])